##  Monitor Progress Using Metrics
To monitor progress, use the following metrics on the onboarding dashboard for enterprise architects. For additional information, see [Understanding Best-Practice Metrics](https://help.sap.com/docs/leanix/ea/application-portfolio-management-onboarding-dashboard-for-enterprise-architects?locale=en-US&state=PRODUCTION&version=CLOUD#loio2758a23c7a441014b785d6548482893a__understanding_best_practice_metrics).
Metrics for Business Capabilities Metric | Explanation
---|---
Level 1 business capabilities: Add a minimum of 7, but no more than 20 to the workspace. Level 2 business capabilities: Add a minimum of 5, but no more than 10 for each level 1 business capability. |  In general, capturing 7-20 business capabilities at level 1 provides a robust foundation and comprehensive overview for organizations. Adhering to the MECE principle (Mutually Exclusive, Completely Exhaustive) becomes challenging with a high number of business capabilities. Avoiding excessive granularity is important to balance effort and productivity. This strategic approach supports initial use cases and provides further insights once a comprehensive business capability model is established. This methodology aligns with capability-based planning, Pace Layering, and strategy/goal alignment.
Add no more than 3 levels of business capability hierarchy to the workspace. | Excessive depth in your categorization may lead to over-compartmentalization, potentially making it challenging for most users to understand business capabilities.
Ensure that at least 80% of business capabilities have a description. | Clear, concise, and universally understood definitions of business capabilities are crucial for your organization and stakeholders. This clarity is key to facilitating effective analysis and generating insightful outcomes within SAP LeanIX.


YesNo
Send
![close icon](https://consent.trustarc.com/get?name=sapglow-close-icon.png)
This site uses cookies and related technologies, as described in our Cookie Statement, for purposes that may include site operation, analytics, enhanced user experience, or advertising. You may choose to consent to our use of these technologies, or manage your own preferences.
Understood Manage Settings
[Privacy Statement](https://help.sap.com/docs/privacy)|[Cookie Statement](https://www.sap.com/about/legal/privacy/cookies.html)
